@@ -11,7 +11,7 @@ ${docdir}/introduction.rst
 # ${docdir}/hacking.rst
 rst2html=$(which rst2html 2> /dev/null > /dev/null && echo rst2html || echo rst2html-3)
 
-cat ${readme_files} > ${output}
-${rst2html} ${output} > /dev/null
+cat ${readme_files} > "${output}"
+${rst2html} "${output}" > /dev/null
 
 # vim:sw=2:ts=2:et:
