@@ -5,8 +5,10 @@
 r"""A Public API to open configuration files by detecting type automatically.
 """
 import typing
+import warnings
 
-from ..common import PathOrIOInfoT
+from ..common import PathOrIOInfoT, IOI_STREAM
+from ..ioinfo import make as ioinfo_make
 from ..parsers import find, MaybeParserT
 from .datatypes import ParserT
 
@@ -31,11 +33,19 @@ def open(path: PathOrIOInfoT, mode: typing.Optional[str] = None,
     :return: A file object or None on any errors
     :raises: ValueError, UnknownProcessorTypeError, UnknownFileTypeError
     """
-    psr: ParserT = find(path, forced_type=ac_parser)
+    if not path:
+        raise ValueError(f'Invalid argument, path: {path!r}')
+
+    ioi = ioinfo_make(path)
+    if ioi.type == IOI_STREAM:
+        warnings.warn(f'Looks already opened stream: {ioi!r}')
+        return typing.cast(typing.IO, ioi.src)
+
+    psr: ParserT = find(ioi, forced_type=ac_parser)
 
     if mode is not None and mode.startswith('w'):
-        return psr.wopen(path, **options)
+        return psr.wopen(ioi.path, **options)
 
-    return psr.ropen(path, **options)
+    return psr.ropen(ioi.path, **options)
 
 # vim:sw=4:ts=4:et:
