@@ -2,7 +2,8 @@
 # Copyright (C) 2011 - 2021 Satoru SATOH <satoru.satoh@gmail.com>
 # SPDX-License-Identifier: MIT
 #
-# Some XML modules may be missing and Base.{load,dumps}_impl are not overriden:
+# Some XML modules may be missing and Base.{load,dumps}_impl are not
+# overridden:
 # pylint: disable=import-error, duplicate-except
 # len(elem) is necessary to check that ET.Element object has children.
 # pylint: disable=len-as-condition
@@ -453,7 +454,8 @@ def etree_write(tree, stream):
         tree.write(stream, encoding='unicode', xml_declaration=True)
 
 
-class Parser(base.Parser, base.ToStreamDumperMixin, base.BinaryFilesMixin):
+class Parser(base.Parser, base.ToStreamDumperMixin,
+             base.BinaryDumperMixin, base.BinaryLoaderMixin):
     """
     Parser for XML files.
     """
