@@ -6,8 +6,10 @@ r"""Public API to query data with JMESPath expression.
 """
 try:
     from .query import try_query
+    SUPPORTED = True
 except ImportError:
     from .default import try_query
+    SUPPORTED = False  # type: ignore
 
 
 __all__ = [
