@@ -14,13 +14,11 @@ instances.
    - Add to abstract processors such like Parsers (loaders and dumpers).
 """
 from .detectors import (
-    is_iterable, is_path, is_path_obj, is_file_stream, is_ioinfo,
+    is_iterable, is_path, is_path_obj, is_ioinfo,
     is_stream_ioinfo, is_path_like_object, is_paths,
     is_dict_like, is_list_like
 )
-from .files import (
-    get_file_extension, get_path_from_stream, expand_paths, are_same_file_types
-)
+from .files import get_path_from_stream
 from .lists import (
     groupby, concat
 )
@@ -30,11 +28,10 @@ from .utils import (
 
 
 __all__ = [
-    'is_iterable', 'is_path', 'is_path_obj', 'is_file_stream', 'is_ioinfo',
+    'is_iterable', 'is_path', 'is_path_obj', 'is_ioinfo',
     'is_stream_ioinfo', 'is_path_like_object', 'is_paths',
     'is_dict_like', 'is_list_like',
-    'get_file_extension', 'get_path_from_stream', 'expand_paths',
-    'are_same_file_types',
+    'get_path_from_stream',
     'groupby', 'concat',
     'filter_options', 'noop',
 ]
